@@ -1,13 +1,18 @@
 ## Define class unions for optional slots, e.g. for definition
 ##  of slots which will be computed on demand, like the
 ##  mahalanobis/robust distances
+## 
+## "Uvector", "Umatrix", "Ulist", "Ufunction", "Utable", "UCovControl"
+## are already defined in rrcov-AllClasses.R
 setClassUnion("Unumeric", c("numeric", "NULL"))
 setClassUnion("Ulogical", c("logical", "NULL"))
 
+
 ###################### FA ####################################
 setClass("Fa", representation(call="language",
 			      converged="Ulogical",
 			      loadings="matrix",
+			      communality="Uvector",
 			      uniquenesses="vector",
 			      correlation="matrix",
 			      criteria="Unumeric",
@@ -16,6 +21,9 @@ setClass("Fa", representation(call="language",
 			      method="character",
 			      scores="Umatrix",
 			      scoresMethod="character",
+			      scoringCoef="Umatrix",
+			      meanF="Uvector",
+			      corF="Umatrix",
 			      STATISTIC="Unumeric",
 			      PVAL="Unumeric",
 			      n.obs="numeric",
